@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.50 $
+//$Revision: 1.55 $
 #include <hk_datasource.h>
 
 #include "hk_kdeboolean.h"
@@ -26,6 +26,7 @@ hk_dsboolean(form)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_kdeboolean::hk_kdeboolean");
+//     wanna_debug(true);
 #endif
     QObject::connect(this,SIGNAL(clicked()),this,SLOT(slot_data_changed()));
     p_widget_specific_row_change=true;
@@ -148,6 +149,19 @@ void hk_kdeboolean::slot_data_changed(void)
 #ifdef HK_DEBUG
     hkdebug("kdeboolean::slotDataChanged");
 #endif
+    if (p_presentation && p_presentation->mode()==hk_presentation::filtermode && !signalsBlocked())
+    {
+	hk_string v;
+            switch (state())
+	    {
+	      case On:v="%TRUE%";break;
+	      case Off:v="%FALSE%";break;
+	      case NoChange:v="";break;
+	    }
+
+    set_filtervalue(v);
+    return;
+    }
     if (!p_widget_specific_row_change)
     {
 #ifdef HK_DEBUG
@@ -259,7 +273,7 @@ bool hk_kdeboolean::widget_specific_coordinates(uint px,uint py,uint pwidth,uint
     hkdebug("hk_kdeboolean::widget_specific_coordinates");
 #endif
     setGeometry(px,py,pwidth,pheight);
-    qApp->processEvents();
+//     qApp->processEvents();
     return true;
 }
 
@@ -381,7 +395,13 @@ void hk_kdeboolean::set_value(const hk_string&v)
 {
  hk_column* c=column();
  hk_dsboolean::set_value(v);
- if (!c)setChecked(string2upper(v)!="FALSE");
+ if (!c)
+   {
+    if (v.size()==0)
+    setNoChange();
+    else
+    setChecked(string2upper(v)!="FALSE");
+   }
 
 }
 
@@ -405,9 +425,34 @@ if (p_presentation->mode()==hk_presentation::designmode)
         setChecked(false);
         blockSignals(false);
    }
+else 
+   if (p_presentation->mode()==hk_presentation::filtermode)
+   {
+    if ( columnname().size()>0)
+    {
+       setEnabled(true);
+        blockSignals(true);
+ 	setTristate(true);
+        setNoChange();
+	if (filtervalue().size()>0)
+	{
+	hk_string v=string2upper(filtervalue());
+	if (v=="=%TRUE% ") setChecked(true);
+	else
+	if (v=="=%FALSE% ") setChecked(false);
+	cerr <<"v=#"<<v<<"#"<<endl;
+	}
+	else
+	cerr <<" mode_changed no filtervalue()"<<endl;
+        blockSignals(false);
+   }
+    else
+      setEnabled(false);
+   }
  else
  {
    setEnabled(is_enabled());
+   if (column())setTristate(!column()->is_notnull());
    if (!datasource()||!column())
     {
         blockSignals(true);
