@@ -676,6 +676,9 @@ if (!p_presentation)
     return hk_button::presentationmode_changed();
   }
 bool result=hk_button::presentationmode_changed();
+   if (p_presentation->mode()==hk_presentation::filtermode)
+   setEnabled(false);
+   else
    setEnabled(is_enabled());
    if (is_togglebutton())set_is_pushed(is_pushed(),false,false);
   return  result;
