@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.72 $
+//$Revision: 1.82 $
 #include <hk_datasource.h>
 #include "hk_kdecombobox.h"
 #include <hk_kdecombobox.moc>
@@ -52,7 +52,7 @@ bool p_while_load_listitems;
 hk_kdecombobox::hk_kdecombobox(QWidget* wid,hk_form* form):QComboBox(wid),hk_dscombobox(form)
 {
 #ifdef HK_DEBUG
-//wanna_debug(true);
+// wanna_debug(true);
     hkdebug("hk_kdecombobox::hk_kdecombobox");
 #endif
     p_private=new hk_kdecomboboxprivate();
@@ -63,6 +63,7 @@ hk_kdecombobox::hk_kdecombobox(QWidget* wid,hk_form* form):QComboBox(wid),hk_dsc
     setDuplicatesEnabled(false);
     setEnabled(false);
     setInsertionPolicy(NoInsertion);
+    p_filter_has_changed=false;
 
     QColor qcolor=paletteBackgroundColor();
     hk_colour colour(qcolor.red(),qcolor.green(),qcolor.red());
@@ -73,14 +74,14 @@ hk_kdecombobox::hk_kdecombobox(QWidget* wid,hk_form* form):QComboBox(wid),hk_dsc
 
     //connect(this,SIGNAL(activated(int)),this,SLOT(slot_data_changed(int)));
     //connect(this,SIGNAL(textChanged( const QString& )),this,SLOT(slot_text_changed()));
-    if (mode()==combo)
-    {
+/*    if (mode()==combo)
+    {*/
     connect(this,SIGNAL(textChanged( const QString& )),this,SLOT(slot_text_changed()));
-    }
+/*    }
     else
-    {
+    {*/
     connect(this,SIGNAL(activated(int)),this,SLOT(slot_data_changed(int)));
-    }
+//     }
     widget_specific_font_changed();
     setLineEdit( new qlineedit(this));
 
@@ -101,7 +102,11 @@ void hk_kdecombobox::slot_data_changed(int index)
 #ifdef HK_DEBUG
     hkdebug("kdecombobox::slot_data_changed");
 #endif
-    set_selecteditemdata(index);
+// cerr <<"slot_data_changed("<<index<<")"<<endl;
+   if ((p_presentation && p_presentation->mode()!=hk_presentation::filtermode)||!p_presentation)
+     if (mode()==combo)
+        return;
+   set_selecteditemdata(index);
     if (p_presentation &&p_presentation->mode()==hk_presentation::viewmode)
        action_on_select();
 
@@ -113,6 +118,16 @@ void hk_kdecombobox::slot_text_changed(void)
 #ifdef HK_DEBUG
     hkdebug("kdecombobox::slot_text_changed");
 #endif
+   if (mode()!=combo) return;
+//     cerr <<"slot_text_changed"<<currentText()<<endl;
+    if (p_presentation && p_presentation->mode()==hk_presentation::filtermode)
+    {    p_filter_has_changed=true;
+    
+    set_filtervalue(u2l(currentText().utf8().data()));
+    
+    return;
+    }
+
     int f=find_edittextitem();
     if (f>-1||viewcolumn()==NULL)
         set_selecteditemdata(f);
@@ -194,7 +209,9 @@ bool hk_kdecombobox::datasource_disable(void)
     hkdebug("kdecombobox::datasource_disable");
 #endif
     before_row_change();
+    blockSignals(true);
     clear();                                      //clears the columnbox
+    blockSignals(false);
     if (listdatasource()!=NULL&& (mode()==combo||mode()==combo_noedit)) listdatasource()->disable();
     return hk_dsdatavisible::datasource_disable();
 
@@ -209,6 +226,15 @@ void hk_kdecombobox::set_currentlistitem(void)
 
     if (datasource()==NULL) return;
     if (column()==NULL) return;
+    
+    
+     if (p_presentation && p_presentation->mode()==hk_presentation::filtermode)
+     {
+       setCurrentText(QString::fromUtf8(l2u(filtervalue()).c_str()));
+       return;
+     }
+    
+    
     if (mode()==combo_noedit)
     {
       unsigned int p=0;
@@ -253,6 +279,15 @@ void hk_kdecombobox::set_selecteditemdata(int index)
         return;
     }
 
+        if (p_presentation && p_presentation->mode()==hk_presentation::filtermode)
+     {
+       setCurrentText("'"+text(index)+"'");
+       slot_focus_lost();
+       return;
+     }
+
+
+
     if (column()==NULL)
     {
     action_on_valuechanged();
@@ -297,7 +332,7 @@ void hk_kdecombobox::set_selecteditemdata(int index)
 bool hk_kdecombobox::widget_specific_coordinates(uint px,uint py,uint pwidth,uint pheight)
 {
     setGeometry(px,py,pwidth,pheight);
-    qApp->processEvents();
+//     qApp->processEvents();
     return true;
 }
 
@@ -316,6 +351,15 @@ void hk_kdecombobox::resizeEvent ( QResizeEvent * event )
 void hk_kdecombobox::keyPressEvent(QKeyEvent * e)
 {
    //p_while_keyaction=true;
+    
+     if (p_presentation && p_presentation->mode()==hk_presentation::filtermode)
+     {
+        QComboBox::keyPressEvent(e);
+        return;
+     }
+
+    
+    
     hk_key nk=hk_key(e->key(),e->state(),(e->text().isNull()?"":u2l(e->text().utf8().data())));
     hk_key* k=NULL;
     if (p_gridcolumn)
@@ -340,6 +384,27 @@ void hk_kdecombobox::keyPressEvent(QKeyEvent * e)
     }
 
 
+        {
+            if ((column()&&column()->is_readonly())||is_readonly())
+            {
+                switch (e->key())
+                {
+                    case Key_Left:
+                    case Key_Right:
+                    case Key_Home:
+                    case Key_End:
+                    case Key_Return: break;
+                    case Key_C: if (e->state()&ControlButton)
+                    {                             //Copy pressed
+                        break;
+                    }
+
+                    default:
+		    //p_while_keyaction=false;
+		    return;
+                }
+            }
+	}
 
     QComboBox::keyPressEvent(e);
     if (e->key()==Key_Escape)
@@ -355,6 +420,7 @@ void hk_kdecombobox::keyPressEvent(QKeyEvent * e)
 
        }
 
+       // if (column()!=NULL)
 /*  if (!e->isAccepted())
      if (datasource()&&datasource()->is_enabled())
         e->accept();*/
@@ -389,6 +455,9 @@ void hk_kdecombobox::reposition(void)
 
 void    hk_kdecombobox::widget_specific_insert_mode(void)
 {
+#ifdef HK_DEBUG
+    hkdebug("kdecombobox::widget_specific_insert_mode");
+#endif
     blockSignals(true);
     unsigned int r=0;
 
@@ -441,11 +510,11 @@ void    hk_kdecombobox::widget_specific_insert_mode(void)
 
 void hk_kdecombobox::load_listitems(void)
 {
+#ifdef HK_DEBUG
+    hkdebug("kdecombobox::load_listitems");
+#endif
    if(p_whiledatachange||p_private->p_while_load_listitems) return;
     p_private->p_while_load_listitems=true;
-    blockSignals(true);
-    clear();
-    blockSignals(false);
   if (use_textlist())
    load_listitems_from_textlist();
   else
@@ -459,6 +528,7 @@ void  hk_kdecombobox::load_listitems_from_textlist(void)
     hkdebug("kdecombobox::load_listitems_from_textlist");
 #endif
     blockSignals(true);
+    clear();
     list<hk_string>* tl=textlist();
     list<hk_string>::iterator it=tl->begin();
     while (it!=tl->end())
@@ -466,6 +536,7 @@ void  hk_kdecombobox::load_listitems_from_textlist(void)
      insertItem(QString::fromUtf8 (l2u((*it)).c_str()));
      ++it;
     }
+    set_currentlistitem();
     blockSignals(false);
 
 }
@@ -482,20 +553,28 @@ void  hk_kdecombobox::load_listitems_from_column(void)
 #ifdef HK_DEBUG
         hkdebug("kdecombobox::load_listitems listdatasource==NULL");
 #endif
+	clear();
 	set_currentlistitem();
 //cout <<"listdatasource==NULL"<<endl;
         blockSignals(false);
         return;
     }
-    listdatasource()->disable();
-    listdatasource()->enable();
-    unsigned int r=listdatasource()->max_rows();
-    if (viewcolumn()!=NULL)
+    if (listdatasource()->depending_on() || count()==0 || 
+         (!listdatasource()->depending_on()
+          && (!listdatasource()->is_enabled() ))
+       )
     {
+     clear();
+     listdatasource()->disable();
+     listdatasource()->enable();
+     unsigned int r=listdatasource()->max_rows();
+     if (viewcolumn()!=NULL)
+     {
         for (unsigned int k=0;k<r;k++)
         {
             insertItem(QString::fromUtf8 (l2u(viewcolumn()->asstring_at(k,true)).c_str()));
         }
+     }
     }
     set_currentlistitem();
     blockSignals(false);
@@ -504,12 +583,18 @@ void  hk_kdecombobox::load_listitems_from_column(void)
 
 void hk_kdecombobox::widget_specific_row_added(void)
 {
-    widget_specific_row_change();
+#ifdef HK_DEBUG
+    hkdebug("kdecombobox::widget_specific_row_added");
+#endif
+   widget_specific_row_change();
 }
 
 
 void hk_kdecombobox::widget_specific_row_deleted(void)
 {
+#ifdef HK_DEBUG
+    hkdebug("kdecombobox::widget_specific_row_deleted");
+#endif
     widget_specific_row_change();
 }
 
@@ -544,19 +629,19 @@ void    hk_kdecombobox::widget_specific_mode_change(void)
 #ifdef HK_DEBUG
     hkdebug("kdecombobox::widget_specific_mode_change");
 #endif
-    disconnect(this,SIGNAL(activated(int)),this,SLOT(slot_data_changed(int)));
-    disconnect(this,SIGNAL(textChanged( const QString& )),this,SLOT(slot_text_changed()));
+//     disconnect(this,SIGNAL(activated(int)),this,SLOT(slot_data_changed(int)));
+//     disconnect(this,SIGNAL(textChanged( const QString& )),this,SLOT(slot_text_changed()));
     if (mode()==combo)
     {
         setEditable(true);
-    connect(this,SIGNAL(textChanged( const QString& )),this,SLOT(slot_text_changed()));
+//     connect(this,SIGNAL(textChanged( const QString& )),this,SLOT(slot_text_changed()));
 
     }
     else
     {
 
         setEditable(false);
-    connect(this,SIGNAL(activated(int)),this,SLOT(slot_data_changed(int)));
+//     connect(this,SIGNAL(activated(int)),this,SLOT(slot_data_changed(int)));
 
     }
 
@@ -635,8 +720,11 @@ void  hk_kdecombobox::mouseDoubleClickEvent(QMouseEvent* event)
 
 void hk_kdecombobox::set_value(const hk_string&v)
 {
+#ifdef HK_DEBUG
+    hkdebug("kdecombobox::set_value");
+#endif
     setEditText(QString::fromUtf8 (l2u(v).c_str()));
-    hk_kdecombobox::set_value(v);
+    hk_dscombobox::set_value(v);
 }
 
 
@@ -648,6 +736,9 @@ hk_string hk_kdecombobox::value(void)
 
 bool	hk_kdecombobox::presentationmode_changed(void)
 {
+#ifdef HK_DEBUG
+    hkdebug("kdecombobox::presentationmode_changed");
+#endif
 bool r=hk_dscombobox::presentationmode_changed();
 if (!r) return false;
 if (!p_presentation) return true;
@@ -658,8 +749,25 @@ if (p_presentation->mode()==hk_presentation::designmode)
         setEditText("");
         blockSignals(false);
    }
+else 
+   if (p_presentation->mode()==hk_presentation::filtermode)
+   {
+    if ( columnname().size()>0 && mode()!=selector)
+    {
+       setEnabled(true);
+       setEditable(true);
+        blockSignals(true);
+        clear();	
+       load_listitems();
+        setCurrentText(QString::fromUtf8(l2u(filtervalue()).c_str()));
+        blockSignals(false);
+    }
+    else
+      setEnabled(false);
+   }
  else
  {
+ widget_specific_mode_change();
    setEnabled(is_enabled());
    if (use_textlist()&&!column())
       load_listitems();
@@ -684,11 +792,35 @@ void hk_kdecombobox::focusInEvent ( QFocusEvent * e)
 
 void hk_kdecombobox::focusOutEvent ( QFocusEvent * e)
 {
+  slot_focus_lost();
   action_on_loosefocus();
   QComboBox::focusOutEvent(e);
 
 }
 
+void    hk_kdecombobox::slot_focus_lost()
+{
+if (!p_filter_has_changed) return;
+   p_filter_has_changed=false;
+   if (p_presentation && p_presentation->mode()==hk_presentation::filtermode && !signalsBlocked())
+    {  
+//     cerr <<"hk_kdecombobox::slot_focus_lost set_filtervalue:"<<currentText()<<endl;
+    if (set_filtervalue(u2l(currentText().utf8().data())))
+    {
+        blockSignals(true);
+        setCurrentText(QString::fromUtf8(l2u(filtervalue()).c_str()));
+        blockSignals(false);
+    }
+    else
+    {
+     hk_string r="Error in statement:#"+ u2l(currentText().utf8().data())+"#";
+     show_warningmessage(r);
+    }
+    
+    }
+
+}
+
 
 void hk_kdecombobox::show_widget(void)
 {
@@ -710,3 +842,16 @@ void hk_kdecombobox::widget_specific_enabled_changed(void)
 {
   setEnabled(is_enabled());
 }
+
+void    hk_kdecombobox::before_presentationmode_changed(void)
+{
+//slot_focus_lost();
+}
+
+
+
+void hk_kdecombobox::update_filter(void)
+{
+slot_focus_lost();
+
+}
