@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.26 $
+//$Revision: 1.32 $
 #include "hk_kdedblistview.h"
 #include <klocale.h>
 #include <kapplication.h>
@@ -77,6 +77,7 @@ void hk_dbviewerdrag::create_draginfo(objecttype type,const QString& object,hk_d
       case ot_view:mystring+="VIEW";break;
       case ot_form:mystring+="FORM";break;
       case ot_report:mystring+="REPORT";break;
+      case ot_module:mystring+="MODULE";break;
     }
     mystring+="</TYPE>\n<DIRECTORY>";
     mystring+=db->database_path()+"/</DIRECTORY>\n<SERVER>";
@@ -85,8 +86,8 @@ void hk_dbviewerdrag::create_draginfo(objecttype type,const QString& object,hk_d
     mystring+=longint2string(db->connection()->tcp_port())+"</TCP>\n<USER>";
     mystring+=db->connection()->user()+"</USER>\n<DBNAME>";
     mystring+=db->name()+"</DBNAME>";
+    mystring="<DRAG>"+mystring+"</DRAG>";
     setEncodedData((QCString)(mystring.c_str()));
-
 }
 
 
@@ -166,6 +167,7 @@ hk_kdedblistviewprivate()
 	p_viewitem=NULL;
 	p_formitem=NULL;
 	p_reportitem=NULL;
+	p_moduleitem=NULL;
 	p_schemadialog=NULL;
 	p_dragging=false;
 	p_showmode=hk_kdedblistview::sm_all;
@@ -176,6 +178,7 @@ KListViewItem* p_viewitem;
 KListViewItem* p_queryitem;
 KListViewItem* p_formitem;
 KListViewItem* p_reportitem;
+KListViewItem* p_moduleitem;
 hk_kdeschemadialog* p_schemadialog;
 hk_kdedblistview::enum_showmode p_showmode;
 void clearList(KListViewItem*);
@@ -240,6 +243,9 @@ void hk_kdedblistview::init_listview()
   p_private->p_databaseitem=new KListViewItem(this,i18n("<No database>"));
   p_private->p_databaseitem->setPixmap(0,loader->loadIcon("contents",KIcon::Small));
 
+  p_private->p_moduleitem=new KListViewItem(p_private->p_databaseitem,i18n("Modules"));
+  p_private->p_moduleitem->setPixmap(0,loader->loadIcon("edit",KIcon::Small));
+
   p_private->p_reportitem=new KListViewItem(p_private->p_databaseitem,i18n("Reports"));
   p_private->p_reportitem->setPixmap(0,loader->loadIcon("fileprint",KIcon::Small));
 
@@ -286,6 +292,8 @@ objecttype hk_kdedblistview::current_objecttype()
         if (is_queryitem(currentItem())) return ot_query;
             else
             if (is_formitem(currentItem())) return ot_form;
+            else
+            if (is_moduleitem(currentItem())) return ot_module;
                 else return ot_report;
 
 }
@@ -317,6 +325,7 @@ set_views();
 set_queries();
 set_forms();
 set_reports();
+set_modules();
 }
 
 void hk_kdedblistview::set_tables(void)
@@ -448,10 +457,44 @@ void hk_kdedblistview::set_reports(void)
       for(it=tb->rbegin();it!=tb->rend();it++)
        new KListViewItem(p_private->p_reportitem,QString::fromUtf8(l2u((*it)).c_str()));
   }
- if (p_private->p_queryitem)p_private->p_queryitem->sortChildItems(0,true);
+ if (p_private->p_reportitem)p_private->p_reportitem->sortChildItems(0,true);
 }
 
 
+
+void hk_kdedblistview::set_modules(void)
+{
+  QString text=i18n("Modules");
+  if (p_database&&
+      ((p_database->loadmode(ft_module)==hk_database::central && p_private->p_showmode==sm_all)
+      ||(p_private->p_showmode==sm_central)
+      )
+     )
+     text+=i18n(" (Central)");
+  p_private->p_moduleitem->setText(0,text);
+
+ p_private->clearList(p_private->p_moduleitem);
+  if (!p_database) return;
+  vector<hk_string>* tb;
+  switch (p_private->p_showmode)
+  {
+    case hk_kdedblistview::sm_central: tb=p_database->central_filelist(ft_module);break;
+    case hk_kdedblistview::sm_local: tb=p_database->local_filelist(ft_module);break;
+    default: tb=p_database->modulelist();
+  }
+  vector<hk_string>::reverse_iterator it;
+  if (tb!=NULL)
+  {
+      for(it=tb->rbegin();it!=tb->rend();it++)
+       new KListViewItem(p_private->p_moduleitem,QString::fromUtf8(l2u((*it)).c_str()));
+  }
+ if (p_private->p_moduleitem)p_private->p_moduleitem->sortChildItems(0,true);
+}
+
+
+
+
+
 void hk_kdedblistview::item_clicked(QListViewItem* item)
 {
   if (p_use_singleclick) item_selected(item);
@@ -496,6 +539,9 @@ else
 else
   if (item->parent()==p_private->p_reportitem)
       emit signal_viewmode_report(item->text(0));
+else
+  if (item->parent()==p_private->p_moduleitem)
+      emit signal_designmode_module(item->text(0));
 else
   if (item==p_private->p_tableitem&& !runtime_only() &&p_database&& p_database->name().size()>0)
       emit signal_new_table();
@@ -511,6 +557,9 @@ else
 else
   if (item==p_private->p_reportitem&& !runtime_only()&&p_database&& p_database->name().size()>0)
       emit signal_new_report();
+else
+  if (item==p_private->p_moduleitem&& !runtime_only()&&p_database&& p_database->name().size()>0)
+      emit signal_new_module();
 else
   if (item==p_private->p_databaseitem&& !runtime_only()&&p_database)
       emit signal_new_database();
@@ -561,6 +610,14 @@ bool hk_kdedblistview::is_reportitem(QListViewItem*item,bool includingheader)
   return false;
 }
 
+bool hk_kdedblistview::is_moduleitem(QListViewItem*item,bool includingheader)
+{
+  if (!item) return false;
+  if (includingheader && item==p_private->p_moduleitem) return true;
+  if (item->parent()==p_private->p_moduleitem) return true;
+  return false;
+}
+
 bool hk_kdedblistview::is_databaseitem(QListViewItem* item)
 {
   if (!item) return false;
@@ -575,6 +632,7 @@ bool hk_kdedblistview::is_headeritem(QListViewItem* item)
 	  item==p_private->p_queryitem ||
 	  item==p_private->p_viewitem ||
 	  item==p_private->p_formitem ||
+	  item==p_private->p_moduleitem ||
 	  item==p_private->p_reportitem
 	 );
 }
@@ -604,6 +662,11 @@ bool hk_kdedblistview::is_reportheader(QListViewItem* item)
    return item==p_private->p_reportitem;
 }
 
+bool hk_kdedblistview::is_moduleheader(QListViewItem* item)
+{
+   return item==p_private->p_moduleitem;
+}
+
 
 
 
@@ -670,6 +733,12 @@ return is_reportitem(currentItem(),includeheader);
 
 }
 
+bool hk_kdedblistview::is_moduleitem(bool includeheader)
+{
+return is_moduleitem(currentItem(),includeheader);
+
+}
+
 bool hk_kdedblistview::is_databaseitem(void)
 {
 return is_databaseitem(currentItem());
@@ -697,6 +766,8 @@ void hk_kdedblistview::new_clicked()
     else
     if (is_reportitem(currentItem(),true)) emit signal_new_report();
     else
+    if (is_moduleitem(currentItem(),true)) emit signal_new_module();
+    else
     if (is_databaseitem(currentItem())) emit signal_new_database();
     else
     if (is_viewitem(currentItem(),true)) emit signal_new_view();
@@ -717,6 +788,8 @@ void hk_kdedblistview::alter_clicked()
     if (is_formitem(currentItem())) emit signal_designmode_form(currentItem()->text(0));
     else
     if (is_reportitem(currentItem())) emit signal_designmode_report(currentItem()->text(0));
+    else
+    if (is_moduleitem(currentItem())) emit signal_designmode_module(currentItem()->text(0));
 }
 
 void hk_kdedblistview::delete_clicked()
@@ -731,6 +804,8 @@ void hk_kdedblistview::delete_clicked()
     else
     if (is_reportitem(currentItem(),true)) emit signal_delete_report(currentItem()->text(0));
     else
+    if (is_moduleitem(currentItem())) emit signal_delete_module(currentItem()->text(0));
+    else
     if (is_databaseitem(currentItem())) emit signal_delete_database(currentItem()->text(0));
 
 
@@ -748,6 +823,8 @@ void hk_kdedblistview::start_clicked()
     if (is_formitem(currentItem())) emit signal_viewmode_form(currentItem()->text(0));
     else
     if (is_reportitem(currentItem())) emit signal_viewmode_report(currentItem()->text(0));
+    else
+    if (is_moduleitem(currentItem())) emit signal_designmode_module(currentItem()->text(0));
 
 }
 
@@ -763,6 +840,8 @@ void    hk_kdedblistview::list_changes(listtype type)
         break;
         case lt_report : set_reports();
         break;
+        case lt_module : set_modules();
+        break;
         default : set_tables();
 
     }
@@ -782,8 +861,11 @@ bool hk_kdedblistview::acceptDrag(QDropEvent* event) const
          cerr <<"event->encodedData ==NULL!!!"<<endl;
 	 return false;
       }
-    hk_string result=event->encodedData("application/x-hk_filecopy").data();
-    hk_class::get_tagvalue(result,"TYPE",xtype);
+    hk_string eventtxt=event->encodedData("application/x-hk_filecopy").data();
+   xmlDocPtr doc=xmlParseMemory(eventtxt.c_str(),eventtxt.size());
+   xmlNodePtr node=xmlDocGetRootElement(doc);
+    
+    hk_class::get_tagvalue(node,"TYPE",xtype);
      if (xtype=="TABLE"
         && !(database()->connection()&&database()->connection()->server_supports(hk_connection::SUPPORTS_NEW_TABLE)))
         cancreate=false;
@@ -810,22 +892,24 @@ bool hk_kdedblistview::decode_action(QMimeSource* event)
 {
     if (!event) return false;
     if (!event->encodedData("application/x-hk_filecopy").data())return false;
-    hk_string result=event->encodedData("application/x-hk_filecopy").data();
+    hk_string eventtxt=event->encodedData("application/x-hk_filecopy").data();
+   xmlDocPtr doc=xmlParseMemory(eventtxt.c_str(),eventtxt.size());
+   xmlNodePtr node=xmlDocGetRootElement(doc);
 
     if (!(
-        hk_class::get_tagvalue(result,"NAME",p_private->xname)
-        &&hk_class::get_tagvalue(result,"TYPE",p_private->xtype)
-        &&hk_class::get_tagvalue(result,"DIRECTORY",p_private->xdirectory)
-        &&hk_class::get_tagvalue(result,"SERVER",p_private->xserver)
-        &&hk_class::get_tagvalue(result,"HOST",p_private->xhost)
-        &&hk_class::get_tagvalue(result,"TCP",p_private->xtcp)
-        &&hk_class::get_tagvalue(result,"USER",p_private->xuser)
-        &&hk_class::get_tagvalue(result,"DBNAME",p_private->xdbname)
+        hk_class::get_tagvalue(node,"NAME",p_private->xname)
+        &&hk_class::get_tagvalue(node,"TYPE",p_private->xtype)
+        &&hk_class::get_tagvalue(node,"DIRECTORY",p_private->xdirectory)
+        &&hk_class::get_tagvalue(node,"SERVER",p_private->xserver)
+        &&hk_class::get_tagvalue(node,"HOST",p_private->xhost)
+        &&hk_class::get_tagvalue(node,"TCP",p_private->xtcp)
+        &&hk_class::get_tagvalue(node,"USER",p_private->xuser)
+        &&hk_class::get_tagvalue(node,"DBNAME",p_private->xdbname)
         )
         )
     {
         show_warningmessage("Error in drag&drop protocol");
-        cerr <<result<<endl;
+        cerr <<eventtxt<<endl;
         return false;
     }
     if (p_private->xtype=="REPORT")
@@ -833,6 +917,11 @@ bool hk_kdedblistview::decode_action(QMimeSource* event)
         p_private->otype=ot_report;
     }
     else
+    if (p_private->xtype=="MODULE")
+    {
+        p_private->otype=ot_module;
+    }
+    else
     if (p_private->xtype=="VIEW")
     {
         p_private->otype=ot_view;
@@ -1075,6 +1164,7 @@ void hk_kdedblistview::reload_lists()
    list_changes(lt_query);
    list_changes(lt_form);
    list_changes(lt_report);
+   list_changes(lt_module);
 
 }
 
