@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.69 $
+//$Revision: 1.73 $
 
 #include "hk_kdeform.h"
 #include "hk_kdeform.moc"
@@ -30,7 +30,9 @@
 #include <kglobal.h>
 #include <kiconloader.h>
 #include <qpushbutton.h>
-#include <hk_kderowselector.h>
+
+#include "hk_kderowselector.h"
+#include "hk_kdeproperty.h"
 #include "../hk_kdegridpart/hk_kdegridpart.h"
 #include <hk_class.h>
 #include <hk_database.h>
@@ -62,7 +64,7 @@ hk_kdeform::hk_kdeform( QWidget* parent,  const char* name, WFlags fl )
     hkdebug("hk_kdeform::hk_kdeform");
 #endif
     p_partmanager=new KParts::PartManager(this);
-    
+
     QString n="Form-SDI";
     KConfig* c=kapp->config();
     QRect rect(0,0,800,600);
@@ -70,8 +72,8 @@ hk_kdeform::hk_kdeform( QWidget* parent,  const char* name, WFlags fl )
     QRect g;
     g=c->readRectEntry("Geometry",&rect);
     setGeometry(g);
-    
-    
+
+
 
     QPixmap p;
     KDockWidget* maindock=createDockWidget("",p,0,"");
@@ -81,22 +83,23 @@ hk_kdeform::hk_kdeform( QWidget* parent,  const char* name, WFlags fl )
     loader->addAppDir("hk_kdeclasses");
     setXMLFile(locate("data","hk_kdeclasses/hk_kdeform.rc"));
 
-    
-    
+
+
     KLibFactory* p_factory= KLibLoader::self()->factory( "libhk_kdeformpart" );
     p_part=(KParts::ReadWritePart*) p_factory->create (maindock, "hk_kdeformpart", "KParts::ReadWritePart");
     if (!p_part)
     {
      show_warningmessage(hk_translate("Fatal error! Form part could not be loaded!\nThis is a installation error. Check your installation!\
- Did you install knoda into the correct directory? Program will exit now...")); 
+ Did you install knoda into the correct directory? Program will exit now..."));
      exit(1);
-    } 
+    }
      p_partmanager->addPart(p_part);
      p_form = (hk_kdeformpartwidget*)p_part->widget();
      maindock->setWidget(p_form);
     setView(maindock);
     setMainDockWidget(maindock);
     connect(p_partmanager,SIGNAL(partRemoved(KParts::Part*)),this, SLOT(part_removed()));
+    connect(p_partmanager,SIGNAL(activePartChanged(KParts::Part*)),this, SLOT(createGUI(KParts::Part*)));
     p_closeaction=new KAction(i18n("&Close"),"fileclose",0,this,SLOT(close_form()),actionCollection(),"closeform");
     createGUI(p_part);
 }
@@ -118,12 +121,12 @@ hk_kdeform::~hk_kdeform()
 void hk_kdeform::part_removed(void)
 {
    cerr <<"hk_kdeform::part_removed"<<endl;
-   
+
    p_part=NULL;
    p_form=NULL;
    close();
-   
-   
+
+
 }
 
 hk_presentation::enum_mode  hk_kdeform::mode(void)
@@ -357,7 +360,7 @@ void hk_kdeform::savedata(ofstream& s)
 }
 
 
-void hk_kdeform::loaddata(const hk_string& definition)
+void hk_kdeform::loaddata(xmlNodePtr definition)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_kdeform::loaddata");
@@ -401,6 +404,7 @@ void hk_kdeform::save_form_when_changed(void)
 
    if (p_form &&p_form->simpleform()->has_changed())
     {
+    if (propertyeditor())propertyeditor()->identifier_changed();
         p_form->simpleform()->save_form();
     }
 
@@ -440,14 +444,14 @@ void hk_kdeform::set_caption(void)
     hk_datasource* d=p_form->simpleform()->datasource();
     if (d!=NULL)
     {
-        if (!v)formname=QString::fromLocal8Bit(d->database()->connection()->drivername().c_str())+" "+formname;
-	
-   
+        if (!v)formname=QString::fromUtf8(l2u(d->database()->connection()->drivername()).c_str())+" "+formname;
+
+
     }
-     formname+=QString::fromLocal8Bit (	
+     formname+=QString::fromUtf8 (l2u(
 	p_form->simpleform()->label().size()>0?
-	p_form->simpleform()->label().c_str():
-	p_form->simpleform()->hk_presentation::name().c_str()
+	p_form->simpleform()->label():
+	p_form->simpleform()->hk_presentation::name()).c_str()
 );
     setCaption( formname  );
     if (v) v->setCaption(formname);
