@@ -39,7 +39,7 @@ class hk_kdegridpart;
  *
  *@short  KDE high level widget to display and design forms
  *@author Horst Knorr (hk_classes@knoda.org)
- *@version $Revision: 1.34 $
+ *@version $Revision: 1.35 $
  *
  *this is a high level widget to display and design forms. It hereby uses @ref hk_kdesimpleform.
  *To use it set the database with @ref set_database. If you want to show or edit an existing form
@@ -108,7 +108,7 @@ class hk_kdeform : public KParts::DockMainWindow,public hk_class
  */
         bool        set_presentationdatasource(long n,bool r=true);
         long        presentationdatasource(void);
-        void        loaddata(const hk_string& definition);
+        void        loaddata(xmlNodePtr);
         void        savedata(ofstream& s);
         void        load_form(const hk_string& n);
 /**
