@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.38 $
+//$Revision: 1.39 $
 #include "hk_kdeformdatasourcedialog.h"
 #include <hk_class.h>
 #include <hk_form.h>
@@ -54,6 +54,10 @@ hk_kdeformdatasourcedialog::hk_kdeformdatasourcedialog( hk_presentation* p, QWid
     p_private->p_edittype=e_all;
     p_private->p_clickedbutton=cb_cancel;
     set_datasource(NULL);
+    hk_database* db=p_private->p_presentation->database();
+    if (db)
+    automaticupdatefield->setChecked(db->is_automatic_data_update());
+    else
     automaticupdatefield->setChecked(true);
     KIconLoader* loader=KGlobal::iconLoader();
     loader->addAppDir("hk_kdeclasses");
