@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.30 $
+//$Revision: 1.37 $
 
 #include "hk_kdeformpartwidget.h"
 #include "hk_kdetoolbar.h"
@@ -38,6 +38,7 @@
 
 #include <kglobal.h>
 #include <kiconloader.h>
+#include <kapplication.h>
 
 #include <hk_class.h>
 #include <hk_database.h>
@@ -224,9 +225,11 @@ hk_kdeformpartwidget::hk_kdeformpartwidget( hk_kdeformpart* formpart,QWidget* pa
 
 
     toolbar = new hk_kdetoolbar( this, "toolbar" );
-    p_filterdefinitionaction=new KAction(i18n("Filterdefinition"),loader->loadIcon("filter",KIcon::User),0,toolbar,SLOT(filterdefinebutton_clicked()),formpart->actionCollection(),"filterdefinition");
+    p_filterdefinitionaction=new KToggleAction(i18n("Filterdefinition"),loader->loadIcon("filter",KIcon::User),0,this,SLOT(filterdefinebutton_clicked()),formpart->actionCollection(),"filterdefinition");
     p_filterexecaction=new KToggleAction(i18n("Filterexecution"),loader->loadIcon("filterexec",KIcon::User),0,toolbar,SLOT(filterexecbutton_clicked()),formpart->actionCollection(),"filterexec");
     toolbar->set_filteractions(p_filterdefinitionaction,p_filterexecaction);
+    
+    p_clearfilteraction=new KAction(i18n("Clear filter"),0,0,this,SLOT(clear_filter()),formpart->actionCollection(),"filterclear");
 
     set_nodesignmode(runtime_only());
     //setCentralWidget(p_scrollview);
@@ -234,6 +237,7 @@ hk_kdeformpartwidget::hk_kdeformpartwidget( hk_kdeformpart* formpart,QWidget* pa
     //toolBar("designtoolbar")->setBarPos(KToolBar::Left);
     set_viewmode();
     connect(p_form,SIGNAL(signal_has_changed()),this,SLOT(slot_has_changed()));
+    connect(p_form,SIGNAL(signal_name_changed()),this,SLOT(set_caption()));
     connect (QApplication::clipboard(), SIGNAL(dataChanged()),this, SLOT(clipboard_changed()));
 p_form->reset_has_changed();
 
@@ -270,8 +274,13 @@ void    hk_kdeformpartwidget::set_mode(hk_presentation::enum_mode s)
     hkdebug("hk_kdeformpartwidget::set_mode(s)");
 #endif
 
-    if (!p_form->set_mode(s))return;
-    if (mode()==hk_presentation::viewmode)
+if (!p_form->set_mode(s))return;
+p_clearfilteraction->setEnabled(s==hk_presentation::filtermode);
+    if ( s!=hk_presentation::filtermode )
+      {
+      p_filterdefinitionaction->setChecked(false);
+       }
+    if (mode()==hk_presentation::viewmode ||mode()==hk_presentation::filtermode)
     {
         p_copyaction->setEnabled(true);
         p_cutaction->setEnabled(false);
@@ -294,11 +303,11 @@ void    hk_kdeformpartwidget::set_mode(hk_presentation::enum_mode s)
     p_resizeaction->setEnabled(mode()==hk_presentation::designmode&&p_form->focus_multipleselected());
     p_alignaction->setEnabled(mode()==hk_presentation::designmode&&p_form->focus_multipleselected());
 
-    if (s==hk_presentation::viewmode)
+    if (s==hk_presentation::viewmode ||mode()==hk_presentation::filtermode)
     {
         //toolBar("designtoolbar")->hide();
         if (p_viewaction)p_viewaction->setChecked(true);
-        toolbar->set_viewmode();
+        if (s==hk_presentation::viewmode )toolbar->set_viewmode();
         p_bulkaction->setEnabled(false);
         p_formpart->setXMLFile(locate("data","hk_kdeclasses/hk_kdeformpartview.rc"));
         p_pointeraction->setEnabled(false);
@@ -572,7 +581,7 @@ void hk_kdeformpartwidget::savedata(ofstream& s)
 }
 
 
-void hk_kdeformpartwidget::loaddata(const hk_string& definition)
+void hk_kdeformpartwidget::loaddata(xmlNodePtr definition)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_kdeformpartwidget::loaddata");
@@ -877,3 +886,37 @@ hk_string hk_kdeformpartwidget::caller_form(void) const
 }
 
 
+
+void hk_kdeformpartwidget::filterdefinebutton_clicked(void)
+{
+ if (p_form->datasource() &&!p_filterdefinitionaction->isChecked())
+ {
+ bool r=p_form->set_formbasedfilter();
+ if (toolbar)toolbar->set_filter(r);
+//  cerr <<"SET FILTER: #"<<r<<"#"<<endl;
+ }
+//  if (p_filterdefinitionaction->isChecked()) p_filterexecaction->setEnabled(false);
+p_form->set_mode(p_filterdefinitionaction->isChecked()?hk_form::filtermode:hk_form::viewmode);
+}
+
+
+
+void hk_kdeformpartwidget::clear_filter()
+{
+list<hk_visible*>* v=p_form->visibles();
+list<hk_visible*>::iterator vit=v->begin();
+while (vit!=v->end())
+{
+  hk_dsdatavisible* ds=dynamic_cast<hk_dsdatavisible*>(*vit);
+  if (ds)
+  {  
+    ds->set_filtervalue("");
+    ds->set_value("");
+    ds->update_filter();
+  }
+  ++vit;
+}
+
+}
+
+
