@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.19 $
+//$Revision: 1.20 $
 
 #include "hk_kdeinterpreterdialog.h"
 #include <qbuttongroup.h>
@@ -43,10 +43,7 @@ class hk_kdeinterpreterdialogprivate
 {
 public:
         KAction*  p_closeaction;
-        KAction*  p_printaction;
-	KAction*  p_clearselectionaction;
-	KAction*  p_toggleinsertaction;
-	KAction*  p_undoaction;
+
 };
 
 /*
@@ -64,47 +61,33 @@ rescode=Accepted;
 
     setXMLFile(locate("data","hk_kdeclasses/hk_kdeinterpreterdialog.rc"));
 
-    KLibFactory* p_factory= KLibLoader::self()->factory( "libkatepart" );
-    p_katepart = (Kate::Document *) p_factory->create (0L, "kate", "KTextEditor::Document");
+    KParts::Factory * p_factory= (KParts::Factory *)KLibLoader::self()->factory( "libkatepart" );
+    p_katepart = (Kate::Document *) p_factory->createPart (0L, "kate",this,"", "KTextEditor::Document");
     p_designkate=(Kate::View *)p_katepart->createView (this, 0L);
     p_has_changed =false;
     setName( "hk_kdeinterpreterdialog" );
     resize( 596, 480 );
-    p_factory= KLibLoader::self()->factory( "libhk_kdegridpart" );
 
 //    p_design = new QMultiLineEdit(this);
-    p_qbe = NULL;                                 //new QWidget(this);
     p_autoclose =true;
-    p_private->p_printaction=new KAction(i18n("&Print"),"fileprint",0,this,SLOT(print()),actionCollection(),"print");
-//p_printaction->setEnabled(false);
     p_private->p_closeaction=new KAction(i18n("&Close"),"fileclose",0,this,SLOT(accept()),actionCollection(),"closedialog");
-    //p_private->p_selectallaction=new KAction( i18n("Select &All"), 0,0, this, SLOT( select_all() ) ,actionCollection(),"selectall");
-    p_private->p_undoaction=new KAction(i18n("&Undo"),"undo",CTRL+Key_Z,this,SLOT(undo()),actionCollection(),"undo");
-    p_private->p_undoaction->setEnabled(false);
 
-    p_private->p_toggleinsertaction= new KAction(i18n("Toggle &Insert"),Key_Insert,this,SLOT(toggle_insert()),actionCollection(),"toggleinsert");
-    KStdAction::replace(p_designkate,SLOT(replace()),actionCollection());
-    KStdAction::find(p_designkate,SLOT(find()),actionCollection());
-    KStdAction::findNext(p_designkate,SLOT(findAgain()),actionCollection());
-    KStdAction::findPrev(p_designkate,SLOT(findPrev()),actionCollection());
-    KStdAction::selectAll(this,SLOT(select_all()),actionCollection());
-    KStdAction::gotoLine(p_designkate,SLOT(gotoLine()),actionCollection());
-    KStdAction::copy(p_designkate,SLOT(copy()),actionCollection());
-    KStdAction::paste(p_designkate,SLOT(paste()),actionCollection());
-    KStdAction::cut(p_designkate,SLOT(cut()),actionCollection());
-    p_private->p_clearselectionaction=new KAction( i18n("Dese&lect"), 0,0, this, SLOT( clear_selection() ) ,actionCollection(),"clearselection");
+    p_designkate->setLineNumbersOn(true);
     setCentralWidget(p_designkate);
-    createGUI(p_katepart);
+     createGUI(NULL);
+   guiFactory()->addClient( p_designkate );
 
     connect( p_designkate->getDoc(), SIGNAL( textChanged() ), this, SLOT( slot_has_changed() ) );
-    p_designkate->setLineNumbersOn(true);
-    connect(p_designkate->getDoc(), SIGNAL(undoChanged()), this, SLOT(slot_undo_changed()));
   KConfig* c=kapp->config();
   QRect rect(0,0,500,300);
   c->setGroup("Interpreter");
   QRect g;
   g=c->readRectEntry("Geometry",&rect);
   setGeometry(g);
+
+
+ 
+
 }
 
 
@@ -115,10 +98,12 @@ hk_kdeinterpreterdialog::~hk_kdeinterpreterdialog()
 {
 // no need to delete child widgets, Qt does it all for us
 hide();
+guiFactory()->removeClient( p_designkate );
 setCentralWidget(NULL);
+delete p_private->p_closeaction;
+
 delete p_designkate;
 delete p_katepart;
-delete p_private->p_closeaction;
 delete p_private;
 }
 
@@ -137,25 +122,12 @@ void hk_kdeinterpreterdialog::closeEvent ( QCloseEvent* e)
 
 
 
-void hk_kdeinterpreterdialog::savebutton_clicked(void)
-{
-    set_caption();
-}
-
-
-void hk_kdeinterpreterdialog::saveasbutton_clicked(void)
-{
-
-
-}
 
 
 
 
-void hk_kdeinterpreterdialog::set_caption(void)
-{
 
-}
+
 
 
 void hk_kdeinterpreterdialog::print(void)
@@ -225,7 +197,6 @@ KConfig* c=kapp->config();
   c->setGroup("Interpreter");
   c->writeEntry("Geometry",geometry());
 
-cerr <<"done close Interpreter"<<endl;
     hide();
     setResult( r );
     //close();
@@ -371,7 +342,6 @@ p_katepart->undo();
 
 void hk_kdeinterpreterdialog::slot_undo_changed(void)
 {
-  p_private->p_undoaction->setEnabled(p_designkate->getDoc()->undoCount()>0);
 }
 
 
