@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.32 $
+//$Revision: 1.33 $
 #include "hk_kdelabel.h"
 #include "hk_kdesimpleform.h"
 #include <qapplication.h>
@@ -58,7 +58,7 @@ bool hk_kdelabel::widget_specific_coordinates(uint px,uint py,uint pwidth,uint p
     hkdebug("kdelabel::widget_specific_coordinates");
 #endif
     setGeometry(px,py,pwidth,pheight);
-    qApp->processEvents();
+//     qApp->processEvents();
 
     return true;
 }
