@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -16,7 +16,7 @@ class hk_kdesimpleform;
 /**
  *
  *@short KDE Widget to display text in a form
- *@version $Revision: 1.17 $
+ *@version $Revision: 1.20 $
  *@author Horst Knorr (hk_classes@knoda.org)
  */
 class hk_kdelabel :public QLabel, public hk_label
@@ -24,6 +24,9 @@ class hk_kdelabel :public QLabel, public hk_label
     Q_OBJECT
         public:
         hk_kdelabel(hk_kdesimpleform* form);
+virtual void show_widget(void);
+virtual void hide_widget(void);
+virtual bool close_widget(void);
     protected:
      virtual void    widget_specific_tooltip_changed(void);
         virtual void    widget_specific_label_changed(void);
@@ -43,6 +46,7 @@ class hk_kdelabel :public QLabel, public hk_label
 	virtual void widget_specific_rightline_changed(void);
 	virtual void widget_specific_diagonalluro_changed(void);
 	virtual void widget_specific_diagonalloru_changed(void);
+	virtual bool	presentationmode_changed(void);
 
     private:
         void    reposition(void);
