@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.15 $
+//$Revision: 1.17 $
 
 #ifndef HK_KDEMESSAGES
 #define HK_KDEMESSAGES
@@ -35,12 +35,16 @@ hk_string hk_kdedriverselectdialog(void);
 
 hk_string hk_kdestringvaluedialog(const hk_string&);
 
+hk_string hk_kdedirectorydialog(const hk_string&);
+
 hk_string hk_kdefiledialog(const hk_string&,enum_operationmode);
 
 void hk_kdedatasourceenablefunction(void);
 
 void set_kdestandarddialogs(void);
 
+hk_string mimetype2driver(const hk_string& mimetype);
+
 class QVBoxLayout;
 class QHBoxLayout;
 class QGridLayout;
