@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_classes library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -19,14 +19,16 @@ class hk_kdenewdatabase : public hk_kdenewdatabasedialogbase
     Q_OBJECT
 
 public:
-    hk_kdenewdatabase( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+    hk_kdenewdatabase( const hk_string& drivername,QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
     ~hk_kdenewdatabase();
-static hk_string show_dialog(bool local);
-    
+static hk_string show_dialog(const hk_string& drivername,bool local);
+
 public slots:
     virtual void ok_clicked();
     virtual void directory_clicked();
     virtual void text_changed();
+private:
+hk_string p_drivername;
 
 };
 
