@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.24 $
+//$Revision: 1.27 $
 
 #include <hk_kdepassworddialog.h>
 #include <klocale.h>
@@ -110,7 +110,7 @@ hk_kdepassworddialog::hk_kdepassworddialog(hk_connection* connection,QWidget* p,
 {
     setMinimumSize( QSize( 300, 250 ) );
     QString c;
-    if (connection) c=QString::fromLocal8Bit(connection->drivername().c_str())+" - ";
+    if (connection) c=QString::fromUtf8(l2u(connection->drivername()).c_str())+" - ";
     c+=i18n("Password Dialog");
     setCaption(c);
     p_connection=connection;
@@ -163,7 +163,7 @@ hk_kdepassworddialog::hk_kdepassworddialog(hk_connection* connection,QWidget* p,
             focus_set=true;
             hostedit->setFocus();
         }
-        if (fields!=0)hostedit->setText(QString::fromLocal8Bit (fields->host.c_str()));
+        if (fields!=0)hostedit->setText(QString::fromUtf8 (l2u(fields->host).c_str()));
     }
     else
     {
@@ -184,11 +184,16 @@ hk_kdepassworddialog::hk_kdepassworddialog(hk_connection* connection,QWidget* p,
 	int i=0;
 	while (it!=dblist->end())
 	{
-	  databasenameedit->insertItem(QString::fromLocal8Bit((*it).c_str()));
+	  databasenameedit->insertItem(QString::fromUtf8(l2u((*it)).c_str()));
 	  if ((*it)==fields->database) databasenameedit->setCurrentItem(i);
 	  ++it;++i;
 	}
-	if (databasenameedit->count()==0)
+	if (databasenameedit && databasenameedit->count()==0 && fields->database.size()>0)
+	{
+		databasenameedit->insertItem(QString::fromUtf8(l2u(fields->database).c_str()));
+		databasenameedit->setCurrentItem(0);
+	}
+//	if (databasenameedit->count()==0)
 	{
 	databasenameedit->setEditable(true);
 	databasenameedit->setAutoCompletion(true);
@@ -196,7 +201,7 @@ hk_kdepassworddialog::hk_kdepassworddialog(hk_connection* connection,QWidget* p,
 	databasenamelabel->setBuddy(databasenameedit);
         fieldlayout->addWidget(databasenameedit);
 
-        //if (fields!=0)databasenameedit->setCurrentText(QString::fromLocal8Bit (fields->database.c_str()));
+        //if (fields!=0)databasenameedit->setCurrentText(QString::fromUtf8 (l2u(fields->database).c_str()));
 /*        if (!focus_set)
         {
             focus_set=true;
@@ -211,7 +216,7 @@ hk_kdepassworddialog::hk_kdepassworddialog(hk_connection* connection,QWidget* p,
     }
 
 
-    
+
     if (p_connection->server_needs(hk_connection::NEEDS_USERNAME))
     {
         userlabel= new QLabel(this,"userlabel");
@@ -221,7 +226,7 @@ hk_kdepassworddialog::hk_kdepassworddialog(hk_connection* connection,QWidget* p,
         userlabel->setBuddy(useredit);
         fieldlayout->addWidget(useredit);
 
-        if (fields!=0)useredit->setText(QString::fromLocal8Bit (fields->user.c_str()));
+        if (fields!=0)useredit->setText(QString::fromUtf8 (l2u(fields->user).c_str()));
         if (!focus_set)
         {
             focus_set=true;
@@ -235,14 +240,14 @@ hk_kdepassworddialog::hk_kdepassworddialog(hk_connection* connection,QWidget* p,
         useredit=NULL;
     }
 
-    
-    
-    
-    
-    
-    
-    
-    
+
+
+
+
+
+
+
+
     if (p_connection->server_needs(hk_connection::NEEDS_PASSWORD))
     {
         passwordlabel= new QLabel(this,"passwordlabel");
@@ -251,7 +256,7 @@ hk_kdepassworddialog::hk_kdepassworddialog(hk_connection* connection,QWidget* p,
         passwordedit= new dialogedit(this,"passwordedit");
         passwordlabel->setBuddy(passwordedit);
         passwordedit->setEchoMode(dialogedit::Password);
-	passwordedit->setText(QString::fromLocal8Bit (fields->password.c_str()));
+	passwordedit->setText(QString::fromUtf8 (l2u(fields->password).c_str()));
         fieldlayout->addWidget(passwordedit);
         if (!focus_set)
         {
@@ -274,7 +279,7 @@ hk_kdepassworddialog::hk_kdepassworddialog(hk_connection* connection,QWidget* p,
 	portedit->setFocusPolicy(ClickFocus);
         portlabel->setBuddy(portedit);
         fieldlayout->addWidget(portedit);
-        if (fields!=0)portedit->setText(QString::fromLocal8Bit (fields->port.c_str()));
+        if (fields!=0)portedit->setText(QString::fromUtf8 (l2u(fields->port).c_str()));
         if (!focus_set)
         {
             focus_set=true;
@@ -296,7 +301,7 @@ hk_kdepassworddialog::hk_kdepassworddialog(hk_connection* connection,QWidget* p,
 	sqldelimiteredit->setFocusPolicy(ClickFocus);
         fieldlayout->addWidget(sqldelimiteredit);
         sqldelimiterlabel->setBuddy(sqldelimiteredit);
-        if (fields!=0)sqldelimiteredit->setText(QString::fromLocal8Bit (fields->sql_delimiter.c_str()));
+        if (fields!=0)sqldelimiteredit->setText(QString::fromUtf8 (l2u(fields->sql_delimiter).c_str()));
         if (!focus_set)
         {
             focus_set=true;
@@ -321,7 +326,7 @@ hk_kdepassworddialog::hk_kdepassworddialog(hk_connection* connection,QWidget* p,
       booleanemulationedit->setFocusPolicy(ClickFocus);
       fieldlayout->addWidget(booleanemulationedit);
       booleanemulationlabel->setBuddy(booleanemulationedit);
-      
+
       if (fields!=0) booleanemulationedit->setCurrentItem(fields->emulateboolean?0:1);
         if (!focus_set)
         {
@@ -334,8 +339,8 @@ hk_kdepassworddialog::hk_kdepassworddialog(hk_connection* connection,QWidget* p,
       booleanemulationedit=NULL;
       booleanemulationlabel=NULL;
     }
-    
-    
+
+
     savesettingslabel= new QLabel(this,"savesettingslabel");
 //      savesettingslabel->setText(i18n("Save settings").c_str());
     textlayout->addWidget(savesettingslabel);
@@ -382,12 +387,12 @@ void hk_kdepassworddialog::ok_buttonclicked()
 {
     if (p_fields!=0)
     {
-        if (p_connection->server_needs(hk_connection::NEEDS_HOST)) p_fields->host=hostedit->text().local8Bit().data();
-        if (p_connection->server_needs(hk_connection::NEEDS_USERNAME)) p_fields->user=useredit->text().local8Bit().data();
-        if (p_connection->server_needs(hk_connection::NEEDS_DATABASENAME)) p_fields->database=databasenameedit->currentText().local8Bit().data();
-        if (p_connection->server_needs(hk_connection::NEEDS_PASSWORD)) p_fields->password=passwordedit->text().local8Bit().data();
-        if (p_connection->server_needs(hk_connection::NEEDS_SQLDELIMITER)) p_fields->sql_delimiter=sqldelimiteredit->text().local8Bit().data();
-        if (p_connection->server_needs(hk_connection::NEEDS_PORT)) p_fields->port=portedit->text().local8Bit().data();
+        if (p_connection->server_needs(hk_connection::NEEDS_HOST)) p_fields->host=u2l(hostedit->text().utf8().data());
+        if (p_connection->server_needs(hk_connection::NEEDS_USERNAME)) p_fields->user=u2l(useredit->text().utf8().data());
+        if (p_connection->server_needs(hk_connection::NEEDS_DATABASENAME)) p_fields->database=u2l(databasenameedit->currentText().utf8().data());
+        if (p_connection->server_needs(hk_connection::NEEDS_PASSWORD)) p_fields->password=u2l(passwordedit->text().utf8().data());
+        if (p_connection->server_needs(hk_connection::NEEDS_SQLDELIMITER)) p_fields->sql_delimiter=u2l(sqldelimiteredit->text().utf8().data());
+        if (p_connection->server_needs(hk_connection::NEEDS_PORT)) p_fields->port=u2l(portedit->text().utf8().data());
         if (booleanemulationedit)p_fields->emulateboolean=(booleanemulationedit->currentItem()==0);
 	p_fields->cancel=false;
         p_fields->save=savesettings->isChecked();
