@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.24 $
+//$Revision: 1.28 $
 
 #include "hk_kdequerypartwidget.h"
 #include "hk_kdequerypartwidget.moc"
@@ -24,6 +24,7 @@
 #include <qimage.h>
 #include <qpixmap.h>
 #include <qmultilineedit.h>
+#include <qprogressdialog.h>
 #include <klocale.h>
 #include <hk_actionquery.h>
 #include <hk_connection.h>
@@ -61,6 +62,8 @@ public:
 };
 
 
+bool    hk_kdequerypartwidget::p_cancel=false;
+QProgressDialog* hk_kdequerypartwidget::p_progressdialog=NULL;
 
 /*
  *  Constructs a hk_kdequerypartwidget which is a child of 'parent', with the
@@ -409,8 +412,11 @@ void hk_kdequerypartwidget::internal_set_viewmode(void)
 	    {
 	     d->set_sql(u2l(p_private->p_designkate->getDoc()->text().utf8().data()),true);
 	    }
-            if ( !d->enable())
-            {
+           d->set_progressdialog(&hk_kdequerypartwidget::set_progress);
+           before_execute();
+        
+           if ( !d->enable())
+            {   after_execute();
                 hk_string reason=hk_translate("Query could not be executed")+"\n"+hk_translate("Servermessage: ")+d->database()->connection()->last_servermessage();
                 show_warningmessage(reason);
                 if (!runtime_only())
@@ -420,6 +426,7 @@ void hk_kdequerypartwidget::internal_set_viewmode(void)
                 }
 
             }
+            after_execute();
         }
         else
         {
@@ -478,6 +485,7 @@ bool  hk_kdequerypartwidget::set_mode(enum_mode s)
     switch (s)
     {
 	case hk_dsmodevisible::designmode :
+	case hk_dsmodevisible::filtermode :
 					internal_set_designmode();
 					break;
 	case hk_dsmodevisible::viewmode :
@@ -785,7 +793,7 @@ void hk_kdequerypartwidget::showMaximized()
 
 void hk_kdequerypartwidget::set_has_changed(enum_has_changed forcesetting)
 {
-//cerr <<"hk_kdequerypartwidget::set_has_changed"<<endl;
+
 hk_dsquery::set_has_changed(forcesetting);
  if (p_saveaction)p_saveaction->setEnabled(!runtime_only()&& has_changed());
 }
@@ -886,3 +894,45 @@ void hk_kdequerypartwidget::storeresult_clicked(void)
   if (!datasource()) return;
   datasource()->database()->copy_table(datasource(),true,false,true);
 }
+
+
+
+
+void    hk_kdequerypartwidget::before_execute(void)
+{
+    p_cancel=false;
+p_progressdialog= new  QProgressDialog(this,NULL,true);
+   p_progressdialog->setCaption(i18n("Executing query ..."));
+   p_progressdialog->setTotalSteps(100);
+   connect(p_progressdialog,SIGNAL(cancelled()),this,SLOT(exec_cancelled()));
+   p_progressdialog->show();
+   qApp->processEvents();
+}
+
+
+void    hk_kdequerypartwidget::after_execute(void)
+{
+  delete p_progressdialog;
+  p_progressdialog=NULL;
+}
+
+
+bool hk_kdequerypartwidget::set_progress(long int position,long int total,const hk_string&txt)
+{
+    if (p_progressdialog)
+    {
+
+        p_progressdialog->setCaption(QString::fromUtf8(l2u(txt).c_str()));
+        p_progressdialog->setTotalSteps(total);
+        p_progressdialog->setProgress(position);
+        p_progressdialog->raise();
+        qApp->processEvents();
+    }
+    return p_cancel;
+}
+
+void hk_kdequerypartwidget::exec_cancelled(void)
+{
+    p_cancel=true;
+
+}
