@@ -133,7 +133,7 @@ void hk_kdereportconditiondialog::set_reportvalues(void)
     list<hk_column*>::iterator it=v->begin();
     while (it!=v->end())
     {
-        reportfield->insertItem(QString::fromLocal8Bit((*it)->name().c_str()));
+        reportfield->insertItem(QString::fromUtf8(l2u((*it)->name()).c_str()));
         it++;
     }
     if (tmpds)
@@ -196,7 +196,7 @@ void hk_kdereportconditiondialog::set_formvalues(void)
     list<hk_column*>::iterator it=v->begin();
     while (it!=v->end())
     {
-        reportfield->insertItem(QString::fromLocal8Bit((*it)->name().c_str()));
+        reportfield->insertItem(QString::fromUtf8(l2u((*it)->name()).c_str()));
         it++;
     }
     if (tmpds)
@@ -240,7 +240,7 @@ void hk_kdereportconditiondialog::set_formdatasources(void)
     list<hk_datasource*>::iterator it=dslist->begin();
     while (it!=dslist->end())
     {
-        QString name= QString::fromLocal8Bit (p_form->unique_datasourcename((*it)->presentationnumber()).c_str());
+        QString name= QString::fromUtf8 (l2u(p_form->unique_datasourcename((*it)->presentationnumber())).c_str());
         formdatasourcefield->insertItem(name);
         it++;
     }
@@ -260,7 +260,7 @@ void hk_kdereportconditiondialog::set_formfields(void)
     if (db==NULL) return;
     QString f=formdatasourcefield->currentText();
     if (f.isEmpty()) f="";
-    hk_datasource* ds= p_form->get_datasource(f.local8Bit().data());
+    hk_datasource* ds= p_form->get_datasource(u2l(f.utf8().data()));
     if (ds==NULL) return;
     list<hk_column*>* v=NULL;
     hk_datasource* tmpds=NULL;
@@ -293,7 +293,7 @@ void hk_kdereportconditiondialog::set_formfields(void)
     list<hk_column*>::iterator it=v->begin();
     while (it!=v->end())
     {
-        formfieldfield->insertItem(QString::fromLocal8Bit ((*it)->name().c_str()));
+        formfieldfield->insertItem(QString::fromUtf8 (l2u((*it)->name()).c_str()));
 
         it++;
     }
@@ -355,10 +355,10 @@ void hk_kdereportconditiondialog::set_buttonvalues(void)
     while (it!=l->end())
     {
         new QListViewItem(conditionlist,
-            QString::fromLocal8Bit ((*it).reportfield.c_str()),
-            QString::fromLocal8Bit ((*it).condition.c_str()),
-            QString::fromLocal8Bit ((*it).formdatasource.c_str()),
-            QString::fromLocal8Bit ((*it).formfield.c_str()));
+            QString::fromUtf8 (l2u((*it).reportfield).c_str()),
+            QString::fromUtf8 (l2u((*it).condition).c_str()),
+            QString::fromUtf8 (l2u((*it).formdatasource).c_str()),
+            QString::fromUtf8 (l2u((*it).formfield).c_str()));
 
         ++it;
     }
@@ -378,7 +378,7 @@ void hk_kdereportconditiondialog::accept(void)
         QString st2 = i->text(1);
         QString st3 = i->text(2);
         QString st4 = i->text(3);
-        p_button->add_condition(st1.local8Bit().data(),st2.local8Bit().data(),st3.local8Bit().data(),st4.local8Bit().data());
+        p_button->add_condition(u2l(st1.utf8().data()),u2l(st2.utf8().data()),u2l(st3.utf8().data()),u2l(st4.utf8().data()));
         i=i->itemBelow();
     }
 
