@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.28 $
+//$Revision: 1.33 $
 
 #include <hk_kderowselector.h>
 #include <hk_kderowselector.moc>
@@ -24,32 +24,19 @@
 #include <qtooltip.h>
 #include <hk_form.h>
 #include <hk_kdeform.h>
+#include <kiconloader.h>
 
 class farleftbutton:public QPushButton
 {
     public:
-        farleftbutton( QWidget* wid):QPushButton(wid){  setFocusPolicy(ClickFocus);}
-    protected:
-        virtual void drawButtonLabel(QPainter* p)
+        farleftbutton( QWidget* wid):QPushButton(wid)
         {
-            int x,y,w,h;
-            x=4;
-            y=3;
-            w=width()-5;h=height()-5;
-            int Lx =w / 2 ;
-            int Ly= h/2 ;
-            if (isDown()){x++;y++;Lx++;Ly++;}
-            Ly--;
-            style().drawPrimitive(QStyle::PE_ArrowLeft,p,QRect(x,y,w,h),colorGroup(),isEnabled()?QStyle::Style_Enabled:QStyle::Style_Default);
-            int l=7;
-            QPen newpen =p->pen();
-            newpen.setWidth(2);
-            p->setPen(newpen);
-            if (!isEnabled())p->setPen(colorGroup().light());
-            else   p->setPen(colorGroup().buttonText());
-            p->drawLine(Lx,Ly,Lx,Ly+l);
-
+          setFocusPolicy(ClickFocus);
+            KIconLoader* loader=KGlobal::iconLoader();
+            loader->addAppDir("hk_kdeclasses");
+            setIconSet(loader->loadIcon("first",KIcon::User));
         }
+    protected:
     private:
 }
 
@@ -58,19 +45,15 @@ class farleftbutton:public QPushButton
 class leftbutton:public QPushButton
 {
     public:
-        leftbutton( QWidget* wid):QPushButton(wid){ setFocusPolicy(ClickFocus);}
-    protected:
-        virtual void drawButtonLabel(QPainter* p)
+        leftbutton( QWidget* wid):QPushButton(wid)
         {
-            int x,y,w,h;
-            x=4;
-            y=3;
-            w=width()-8;h=height()-5;
-            int Lx =w / 2 -2;
-            int Ly= h/2 ;
-            if (isDown()){x++;y++;Lx++;Ly++;}
-            style().drawPrimitive(QStyle::PE_ArrowLeft,p,QRect(x,y,w,h),colorGroup(),isEnabled()?QStyle::Style_Enabled:QStyle::Style_Default);
+          setFocusPolicy(ClickFocus);
+            KIconLoader* loader=KGlobal::iconLoader();
+            loader->addAppDir("hk_kdeclasses");
+            setIconSet(loader->loadIcon("previous",KIcon::User));
         }
+
+    protected:
     private:
 }
 
@@ -79,19 +62,15 @@ class leftbutton:public QPushButton
 class rightbutton:public QPushButton
 {
     public:
-        rightbutton( QWidget* wid):QPushButton(wid){ setFocusPolicy(ClickFocus);}
-    protected:
-        virtual void drawButtonLabel(QPainter* p)
+        rightbutton( QWidget* wid):QPushButton(wid)
         {
-            int x,y,w,h;
-            x=4;
-            y=3;
-            w=width()-8;h=height()-5;
-            int Lx =w / 2 -2;
-            int Ly= h/2 ;
-            if (isDown()){x++;y++;Lx++;Ly++;}
-            style().drawPrimitive(QStyle::PE_ArrowRight,p,QRect(x,y,w,h),colorGroup(),isEnabled()?QStyle::Style_Enabled:QStyle::Style_Default);
+          setFocusPolicy(ClickFocus);
+            KIconLoader* loader=KGlobal::iconLoader();
+            loader->addAppDir("hk_kdeclasses");
+            setIconSet(loader->loadIcon("next",KIcon::User));
         }
+
+    protected:
     private:
 }
 
@@ -100,28 +79,15 @@ class rightbutton:public QPushButton
 class farrightbutton:public QPushButton
 {
     public:
-        farrightbutton( QWidget* wid):QPushButton(wid){ setFocusPolicy(ClickFocus);}
-    protected:
-        virtual void drawButtonLabel(QPainter* p)
+        farrightbutton( QWidget* wid):QPushButton(wid)
         {
-            int x,y,w,h;
-            x=4;
-            y=3;
-            w=width()-10;h=height()-5;
-            int Lx =w / 2 +7;
-            int Ly= h/2 ;
-            if (isDown()){x++;y++;Lx++;Ly++;}
-            Ly--;
-            style().drawPrimitive(QStyle::PE_ArrowRight,p,QRect(x,y,w,h),colorGroup(),isEnabled()?QStyle::Style_Enabled:QStyle::Style_Default);
-            int l=7;
-            QPen newpen =p->pen();
-            newpen.setWidth(2);
-            p->setPen(newpen);
-            if (!isEnabled())p->setPen(colorGroup().light());
-            else   p->setPen(colorGroup().buttonText());
-            p->drawLine(Lx,Ly,Lx,Ly+l);
-
+          setFocusPolicy(ClickFocus);
+            KIconLoader* loader=KGlobal::iconLoader();
+            loader->addAppDir("hk_kdeclasses");
+            setIconSet(loader->loadIcon("last",KIcon::User));
         }
+
+    protected:
     private:
 }
 
@@ -131,23 +97,14 @@ class farrightbutton:public QPushButton
 class deletebutton:public QPushButton
 {
     public:
-        deletebutton( QWidget* wid):QPushButton(wid){ setFocusPolicy(ClickFocus);}
-    protected:
-        virtual void drawButtonLabel(QPainter* p)
+        deletebutton( QWidget* wid):QPushButton(wid)
         {
-            int x,y,w,h;
-            x=2;y=2;w=width();h=height();
-            int Lx =w / 2 -3;
-            int Ly= h/2 ;
-            if (isDown()){x++;y++;Lx++;Ly++;}
-            int l=5;
-            QPen newpen =p->pen();
-            newpen.setWidth(2);
-            p->setPen(newpen);
-            if (!isEnabled())p->setPen(colorGroup().light());
-            else   p->setPen(colorGroup().buttonText());
-            p->drawLine(Lx,Ly,Lx+l,Ly);
+          setFocusPolicy(ClickFocus);
+            KIconLoader* loader=KGlobal::iconLoader();
+            loader->addAppDir("hk_kdeclasses");
+            setIconSet(loader->loadIcon("delete",KIcon::User));
         }
+    protected:
     private:
 }
 
@@ -157,24 +114,15 @@ class deletebutton:public QPushButton
 class addbutton:public QPushButton
 {
     public:
-        addbutton( QWidget* wid):QPushButton(wid){ setFocusPolicy(ClickFocus);}
-    protected:
-        virtual void drawButtonLabel(QPainter* p)
+        addbutton( QWidget* wid):QPushButton(wid)
         {
-            int x,y,w,h;
-            x=2;y=2;w=width();h=height();
-            int Lx =w / 2 -3;
-            int Ly= h/2 ;
-            if (isDown()){x++;y++;Lx++;Ly++;}
-            int l=5;
-            if (!isEnabled())p->setPen(colorGroup().light());
-            else   p->setPen(colorGroup().buttonText());
-            QPen newpen =p->pen();
-            newpen.setWidth(2);
-            p->setPen(newpen);
-            p->drawLine(Lx,Ly,Lx+l+1,Ly);
-            p->drawLine(w/2,Ly-3,w/2,Ly+3);
+          setFocusPolicy(ClickFocus);
+            KIconLoader* loader=KGlobal::iconLoader();
+            loader->addAppDir("hk_kdeclasses");
+            setIconSet(loader->loadIcon("add",KIcon::User));
         }
+
+    protected:
     private:
 }
 
@@ -184,23 +132,15 @@ class addbutton:public QPushButton
 class storebutton:public QPushButton
 {
     public:
-        storebutton( QWidget* wid):QPushButton(wid){ setFocusPolicy(ClickFocus);}
-    protected:
-        virtual void drawButtonLabel(QPainter* p)
+        storebutton( QWidget* wid):QPushButton(wid)
         {
-            int x,y,w,h;
-            x=2;y=2;w=width();h=height();
-            int Lx =w / 2 -3;
-            int Ly= h/2 ;
-            if (isDown()){x++;y++;Lx++;Ly++;}
-//		int l=5;
-            if (!isEnabled())p->setPen(colorGroup().light());
-            else   p->setPen(colorGroup().buttonText());
-            QPen newpen =p->pen();
-            newpen.setWidth(2);
-            p->setPen(newpen);
-            p->drawText(Lx+2,Ly+5,"!");
+          setFocusPolicy(ClickFocus);
+            KIconLoader* loader=KGlobal::iconLoader();
+            loader->addAppDir("hk_kdeclasses");
+            setIconSet(loader->loadIcon("store",KIcon::User));
         }
+
+    protected:
     private:
 }
 
@@ -613,7 +553,7 @@ void    hk_kderowselector::widget_specific_foregroundcolour_changed(const hk_col
 
 void  hk_kderowselector::widget_specific_tooltip_changed(void)
 {
- QToolTip::add(this,QString::fromLocal8Bit (tooltip().c_str()));
+ QToolTip::add(this,QString::fromUtf8 (l2u(tooltip()).c_str()));
 }
 
 
@@ -632,4 +572,16 @@ void hk_kderowselector::focusOutEvent ( QFocusEvent * e)
 
 }
 
+void hk_kderowselector::widget_specific_enabled_changed(void)
+{
+  setEnabled(is_enabled());
+}
+
+bool	hk_kderowselector::presentationmode_changed(void)
+{
+ bool result=hk_dsrowselector::presentationmode_changed();
+  setEnabled(is_enabled());
+  return result;
+}
+
 
