@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.129 $
+//$Revision: 1.140 $
 #include "hk_kdesimpleform.h"
 #include "hk_kdeform.h"
 #include "hk_kdeformpartwidget.h"
@@ -36,6 +36,8 @@
 #include "hk_datasource.h"
 
 #include <qkeycode.h>
+#include <qdatetime.h>
+#include <qeventloop.h>
 #include <qpopupmenu.h>
 #include <qfocusdata.h>
 #include <qpainter.h>
@@ -89,6 +91,7 @@ KAction * p_dbdesigneraction;
 KDockWidget* p_propertydock;
 QRect p_moverect;
 bool p_already_selected_widget_clicked;
+QColor p_filtercolourbuffer;
 };
 
 
@@ -139,6 +142,7 @@ hk_kdesimpleform::hk_kdesimpleform(QWidget* wid,const char* n,WFlags f) :QWidget
     QColor qcolor=paletteBackgroundColor();
     hk_colour colour(qcolor.red(),qcolor.green(),qcolor.red());
     set_backgroundcolour(colour,false,true);
+    p_private->p_filtercolourbuffer=qcolor;
     qcolor=paletteForegroundColor();
     colour.set_colour(qcolor.red(),qcolor.green(),qcolor.red());
     set_foregroundcolour(colour,false,true);
@@ -330,7 +334,6 @@ hk_dsdate*       hk_kdesimpleform::widget_specific_new_date(void)
 hk_dsimage*      hk_kdesimpleform::widget_specific_new_image(void)
 {
 hk_kdeimage* i=new hk_kdeimage(this,this);
-cerr <<"new_image"<<endl;
 #ifdef HK_DEBUG
     i->show();
     i->hkclassname("image");
@@ -592,7 +595,7 @@ hk_visible* hk_kdesimpleform::create_field(const QPoint& position)
 
 void hk_kdesimpleform::paintEvent(QPaintEvent* e)
 {
-    if (mode()==hk_presentation::viewmode)
+    if (mode()==hk_presentation::viewmode ||mode()==hk_presentation::filtermode)
     {
         QWidget::paintEvent(e) ;
         return;
@@ -924,8 +927,8 @@ void hk_kdesimpleform::widget_specific_modechanges(enum_mode s)
 	 }
 	 //cerr <<"FOCUS SETZEN"<<w->className()<<endl;
 	}
-	else
-	cerr <<" NO FOCUS"<<endl;
+// 	else
+// 	cerr <<" NO FOCUS"<<endl;
         }
     }
     enable_actions();
@@ -935,7 +938,7 @@ void hk_kdesimpleform::widget_specific_modechanges(enum_mode s)
 void hk_kdesimpleform::widget_specific_after_loadform(void)
 {
     clearfocus();
-    qApp->processEvents();
+//     qApp->processEvents();
 }
 
 
@@ -1204,6 +1207,12 @@ void hk_kdesimpleform::mousemenu(QMouseEvent* m)
     p_settoall->insertItem(i18n("Font"),19);
     p_settoall->insertItem(i18n("Foregroundcolour"),20);
     p_settoall->insertItem(i18n("Backgroundcolour"),21);
+#ifdef HK_DEBUG
+        hk_visible* v=dynamic_cast<hk_visible*>(p_focus->widget());
+        p_popup->insertSeparator();
+        p_popup->insertItem(((v?v->wanna_debug():wanna_debug())?i18n("Don't debug"):i18n("Debug")),99);
+        p_popup->insertSeparator();
+#endif
 
         QWidget* gridwidget=NULL;
         QWidget* object =p_focus->widget();
@@ -1332,6 +1341,19 @@ void hk_kdesimpleform::mousemenu(QMouseEvent* m)
         case 19:    set_for_all(bulkfont);break;
         case 20:    set_for_all(bulkforeground);break;
         case 21:    set_for_all(bulkbackground);break;
+#ifdef HK_DEBUG
+        case 99: 
+                    {
+                    hk_visible* v=dynamic_cast<hk_visible*>(p_focus->widget());
+                    if (v)
+                    {
+                    v->wanna_debug(!v->wanna_debug()); 
+                    }
+                    else
+                    wanna_debug(!wanna_debug()); 
+                    break;
+                    }
+#endif
         default:;
     }
 
@@ -1705,7 +1727,8 @@ STRINGSTREAM stream;
     {
         cpyinfo+=c;
     }
-//cout <<"cpyinfo "<<endl<<cpyinfo <<endl;
+    cpyinfo="<DRAG>"+cpyinfo+"</DRAG>";
+// cout <<"cpyinfo "<<endl<<cpyinfo <<endl;
 
     QCString cstr =cpyinfo.c_str();
     p_drag->setEncodedData(cstr);
@@ -1720,12 +1743,15 @@ void hk_kdesimpleform::paste_widgets(void)
     if (!QApplication::clipboard()->data()->encodedData("application/x-hk_kdesimpleformcopy"))return ;
     clearfocus();
     //p_controlbutton=true;
-    hk_string definition=u2l(QApplication::clipboard()->data()->encodedData("application/x-hk_kdesimpleformcopy").data());
-    cout <<"einzufgen=:"<<endl<<definition<<endl<<"ENDE"<<endl;
+    hk_string def=QApplication::clipboard()->data()->encodedData("application/x-hk_kdesimpleformcopy").data();
+     xmlDocPtr doc=xmlParseMemory(def.c_str(),def.size());
+     xmlNodePtr definition=xmlDocGetRootElement(doc);
+     if (!definition) return;
     int i=1;
-    hk_string value;
+    xmlNodePtr value;
     hk_string buffer2;
-    while (get_tagvalue(definition,"FORMOBJECT",value,i))
+    hk_string xxx;
+    while ((value=get_tagvalue(definition,"FORMOBJECT",xxx,i)))
     {
         get_tagvalue(value,"VISIBLETYPE",buffer2);
         hk_visible* vis=new_object(buffer2);
@@ -1783,6 +1809,7 @@ bool    hk_kdesimpleform::set_mode(enum_mode s)
     {
      return true;
     }
+   interpreter()->set_block_execution(s==filtermode);
     p_private->while_modechange=true;
     bool r=hk_form::set_mode(s);
     if (!r)
@@ -1790,6 +1817,7 @@ bool    hk_kdesimpleform::set_mode(enum_mode s)
      p_private->while_modechange=false;
      return false;
      }
+   setPaletteBackgroundColor(p_private->p_filtercolourbuffer);
    if (s==hk_presentation::viewmode)
     {
     setEnabled(is_enabled());
@@ -1804,9 +1832,25 @@ bool    hk_kdesimpleform::set_mode(enum_mode s)
     else
     {
     setEnabled(true);
+    if (s==filtermode)
+    {
+    QColor newcolour(Qt::yellow);
+    setPaletteBackgroundColor(newcolour);
+      if (p_formpropertyaction)p_formpropertyaction->setEnabled(false);
+	if (p_private->p_designer)
+		{
+			delete p_private->p_designer;
+			p_private->p_designer=NULL;
+		}
+    
+    }
+    else //designmode
+    
+    {
     if (p_property)p_property->setEnabled(true);
         if(p_formpropertyaction)p_formpropertyaction->setEnabled(true);
 
+    }
     }
     if (p_kdeform)p_kdeform->set_mode(s);
     else
@@ -1814,6 +1858,7 @@ bool    hk_kdesimpleform::set_mode(enum_mode s)
     p_private->while_modechange=false;
 
     return r;
+    
 
 }
 
@@ -1884,6 +1929,7 @@ void    hk_kdesimpleform::widget_specific_backgroundcolour_changed(const hk_colo
     QColor newcolour(c.red(),c.green(),c.blue());
     setPaletteBackgroundColor(newcolour);
     list<hk_visible*>::iterator it=visibles()->begin();
+    p_private->p_filtercolourbuffer=newcolour;
     while (it!=visibles()->end())
     {
         switch ((*it)->type())
@@ -2405,7 +2451,7 @@ bool hk_kdesimpleform::widget_specific_coordinates(uint px,uint py,uint ,uint )
 #endif
     if (p_kdeform ||p_formpartwidget) return true;
     move(px,py);
-    qApp->processEvents();
+//     qApp->processEvents();
 
     return true;
 }
@@ -2451,7 +2497,7 @@ if (!p_property) return;
 
 void hk_kdesimpleform::widget_specific_enabled_changed(void)
 {
-cerr <<"widget_specific_enabled_changed: "<<(is_enabled()?"true":"false")<<endl;
+// cerr <<"widget_specific_enabled_changed: "<<(is_enabled()?"true":"false")<<endl;
   //if (mode()==viewmode)setEnabled(is_enabled());
 }
 
@@ -2465,3 +2511,21 @@ int hk_kdesimpleform::screen_height()
   return QApplication::desktop()->screenGeometry(this).height();
 }
 
+
+bool hk_kdesimpleform::intervaltasks(void)
+{
+cerr <<"hk_kdesimpleform::intervaltasks"<<endl;
+//  QApplication::eventLoop()->processEvents(QEventLoop::AllEvents);
+cerr <<"pendingevents:"<<qApp->hasPendingEvents()<<" time:"<<QTime::currentTime().toString()<<endl;
+cerr <<"NACH processEvents()"<<endl;
+return true;
+}
+
+
+void hk_kdesimpleform::widget_specific_set_name(void)
+{
+  emit signal_name_changed();
+}
+
+
+
