@@ -28,7 +28,7 @@ class  KActionCollection;
 /**
  *
  *@short KDE Widget to display forms.
- *@version $Revision: 1.54 $
+ *@version $Revision: 1.57 $
  *@author Horst Knorr (hk_classes@knoda.org)
  *
  *hk_kdesimpleform is a KDE widget to display and alter forms.
@@ -79,6 +79,7 @@ virtual bool close_widget(void);
         void signal_closed(QWidget*);
 	void signal_focuswidget_changed(void);
 	void signal_has_changed(void);
+	void signal_name_changed(void);
 
     public slots:
         void set_field2create(enum_visibletype);
@@ -112,6 +113,7 @@ virtual        void show_property(void);
 virtual bool show_asdialog(hk_form* parentform=NULL);
 virtual int screen_width();
 virtual int screen_height();
+virtual bool intervaltasks(void);
 
     protected:
         virtual void closeEvent ( QCloseEvent* e);
@@ -125,6 +127,7 @@ virtual int screen_height();
 	void set_actions(KActionCollection*);
 	bool has_already_focus(QWidget*);
         virtual bool    widget_specific_coordinates(uint px,uint py,uint pwidth,uint pheight);
+        virtual void widget_specific_set_name(void);
 
         virtual hk_dsgrid*      widget_specific_new_grid(void);
         virtual hk_dsrowselector*   widget_specific_new_rowselector(void);
