@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.76 $
+//$Revision: 1.78 $
 
 #include "hk_kdesimplereport.h"
 #include "hk_kdereportsection.h"
@@ -1476,6 +1476,7 @@ void hk_kdesimplereport::copy_widgets(void)
     {
         cpyinfo+=c;
     }
+    cpyinfo="<DRAG>"+cpyinfo+"</DRAG>";
 //cout <<"cpyinfo "<<endl<<cpyinfo <<endl;
 
     QCString cstr =cpyinfo.c_str();
@@ -1491,17 +1492,19 @@ void hk_kdesimplereport::paste_widgets(void)
     if (!QApplication::clipboard()->data()->encodedData("application/x-hk_kdesimplereportcopy"))return ;
     clearfocus();
     //p_private->p_controlbutton=true;
-    hk_string definition=u2l(QApplication::clipboard()->data()->encodedData("application/x-hk_kdesimplereportcopy").data());
+    hk_string def=u2l(QApplication::clipboard()->data()->encodedData("application/x-hk_kdesimplereportcopy").data());
+     xmlDocPtr doc=xmlParseMemory(def.c_str(),def.size());
+     xmlNodePtr definition=xmlDocGetRootElement(doc);
     int i=1;
-    hk_string value;
-    hk_string buffer2;
+    xmlNodePtr value;
+    hk_string xxx,buffer2;
     hk_kdereportsection* rs=dynamic_cast<hk_kdereportsection*>((p_private->p_focussection?p_private->p_focussection:datasection()));
     if (!rs)
     {
         show_warningmessage(u2l(i18n("Error while paste action: No reportsection!!!").utf8().data()));
         return;
     }
-    while (get_tagvalue(definition,"REPORTOBJECT",value,i))
+    while ((value=get_tagvalue(definition,"REPORTOBJECT",xxx,i)))
     {
 
         hk_reportdata* vis=rs->new_data();
