@@ -77,6 +77,12 @@ void hk_kdesubform::reposition(void)
 bool hk_kdesubform::presentationmode_changed(void)
 {
  bool result=hk_subform::presentationmode_changed();
+ if (p_presentation && p_presentation->mode()==hk_presentation::filtermode)
+ {
+   setEnabled(false);
+   return result;
+ }
+ else setEnabled(is_enabled());
  if (!result) return false;
  if (p_presentation && p_presentation->mode()==hk_presentation::viewmode)
     ((hk_kdesimpleform*)(subform()))-> repaint();
