@@ -27,13 +27,14 @@ class QHBoxLayout;
 class QGridLayout;
 class QButtonGroup;
 class QTable;
+class QProgressDialog;
 class hk_kdetoolbar;
 class hk_kdetablepart;
 
 /**
  *
  *@short  KDE high level widget to display and alter tables.
- *@version $Revision: 1.7 $
+ *@version $Revision: 1.9 $
  *@author Horst Knorr (hk_classes@knoda.org)
 
  *hk_kdetablepartwidget is a high level widget to display the content of tables and to define and alter the
@@ -95,7 +96,7 @@ virtual bool close_widget(void);
 
 	KRadioAction* p_designaction;
         KRadioAction* p_viewaction;
-        KAction*      p_filterdefinitionaction;
+        KToggleAction*      p_filterdefinitionaction;
         KToggleAction*    p_filterexecaction;
         KAction*  p_printaction;
         KAction* p_columndialogaction;
@@ -103,12 +104,19 @@ virtual bool close_widget(void);
         KAction* p_copyaction;
         KAction* p_pasteaction;
 	KAction* p_saveaction;
+ static  bool set_progress(long int,long int,const hk_string&);
 
+    protected slots:
+            void exec_cancelled(void);
 
 
     private:
         bool p_autoclose;
         KParts::ReadWritePart* p_gridpart;
+static        QProgressDialog* p_progressdialog;
+         static bool p_cancel;
+        void before_execute(void);
+        void after_execute(void);
 
 };
 #endif                                            // HK_KDETABLEPARTWIDGET_H
