@@ -8,16 +8,20 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-// $Revision: 1.7 $
+// $Revision: 1.8 $
 #include "hk_kdetaborder.h"
 #include "hk_kdesimpleform.h"
 #include <hk_class.h>
+#include <hk_dsdatavisible.h>
 
 #include <qlistview.h>
 #include <qpushbutton.h>
 #include <qtoolbutton.h>
 
 #include <kiconloader.h>
+#include <klocale.h>
+#include <kconfig.h>
+#include <kapplication.h>
 
 /* 
  *  Constructs a hk_kdetaborder which is a child of 'parent', with the 
@@ -40,7 +44,14 @@ p_form=f;
 taborderlist->setSorting(-1);
 if (!p_form) hk_class::show_warningmessage("hk_kdetaborder ERROR form is NULL!!!");
 p_has_changed=false;
-init();cerr <<"nach init"<<endl;
+init();
+  KConfig* c=kapp->config();
+  QRect rect(0,0,500,300);
+  c->setGroup("Taborder");
+  QRect g;
+  g=c->readRectEntry("Geometry",&rect);
+  setGeometry(g);
+
 check_buttons();
 }
 
@@ -54,8 +65,31 @@ while (it!=t.rend())
   hk_visible* v=p_form->get_visible(*it);
   QString n;
      n.setNum(*it);
+  QString type;
+  
+  
   if (v)
-    new QListViewItem(taborderlist,n,QString::fromUtf8(l2u(v->identifier()).c_str()));
+  {
+    switch (v->type())
+    {
+     case hk_visible::button: type=i18n("button");break;
+     case hk_visible::rowselector: type=i18n("rowselector");break;
+     case hk_visible::boolean: type=i18n("boolean");break;
+     case hk_visible::lineedit: type=i18n("lineedit");break;
+     case hk_visible::memo: type=i18n("memo");break;
+     case hk_visible::combobox: type=i18n("combobox");break;
+     case hk_visible::grid: type=i18n("grid");break;
+     case hk_visible::subform: type=i18n("subform");break;
+     case hk_visible::image: type=i18n("image");break;
+     case hk_visible::tabvisible: type=i18n("tabvisible");break;
+     default: type=i18n("unknown");
+    }
+    QString col;
+    hk_dsdatavisible* dv=dynamic_cast<hk_dsdatavisible*>(v);
+    if (dv)
+      col=QString::fromUtf8(dv->columnname().c_str());
+    new QListViewItem(taborderlist,n,QString::fromUtf8(l2u(v->identifier()).c_str()),type,col);
+  }
   ++it;
 }
 taborderlist->setAllColumnsShowFocus(true);
@@ -89,8 +123,31 @@ while (it!=t.rend())
   hk_visible* v=p_form->get_visible(*it);
   QString n;
      n.setNum(*it);
+  QString type;
+  
+  
   if (v)
-    new QListViewItem(baselist,n,QString::fromUtf8(l2u(v->identifier()).c_str()));
+  {
+    switch (v->type())
+    {
+     case hk_visible::button: type=i18n("button");break;
+     case hk_visible::rowselector: type=i18n("rowselector");break;
+     case hk_visible::boolean: type=i18n("boolean");break;
+     case hk_visible::lineedit: type=i18n("lineedit");break;
+     case hk_visible::memo: type=i18n("memo");break;
+     case hk_visible::combobox: type=i18n("combobox");break;
+     case hk_visible::grid: type=i18n("grid");break;
+     case hk_visible::subform: type=i18n("subform");break;
+     case hk_visible::image: type=i18n("image");break;
+     case hk_visible::tabvisible: type=i18n("tabvisible");break;
+     default: type=i18n("unknown");
+    }
+    QString col;
+    hk_dsdatavisible* dv=dynamic_cast<hk_dsdatavisible*>(v);
+    if (dv)
+      col=QString::fromUtf8(dv->columnname().c_str());
+    new QListViewItem(baselist,n,QString::fromUtf8(l2u(v->identifier()).c_str()),type,col);
+   }
   ++it;
 }
 
@@ -119,7 +176,7 @@ void hk_kdetaborder::add_clicked()
 {
    if (!baselist->currentItem()) return;
    QListViewItem* c=baselist->currentItem();
-   new QListViewItem(taborderlist,taborderlist->lastItem(),c->text(0),c->text(1));
+   new QListViewItem(taborderlist,taborderlist->lastItem(),c->text(0),c->text(1),c->text(2),c->text(3));
    baselist->setCurrentItem(c->itemAbove());
    delete c;
     
@@ -153,7 +210,7 @@ void hk_kdetaborder::delete_clicked()
 {
    if (!taborderlist->currentItem()) return;
    QListViewItem* c=taborderlist->currentItem();
-   new QListViewItem(baselist,c->text(0),c->text(1));
+   new QListViewItem(baselist,c->text(0),c->text(1),c->text(2),c->text(3));
    taborderlist->setCurrentItem(c->itemAbove());
    delete c;
     
@@ -206,6 +263,10 @@ void hk_kdetaborder::ok_clicked()
     ++it;
   }
   p_form->set_taborder(i);
+  KConfig* c=kapp->config();
+  c->setGroup("Taborder");
+  c->writeEntry("Geometry",geometry());
+
   accept();
 }
 
