@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.47 $
+//$Revision: 1.51 $
 #include "knodamaindockwindow.h"
 #include "hk_kdedblistview.h"
 #include "hk_kdecsvimportdialog.h"
@@ -21,6 +21,7 @@
 #include "hk_kdequerypartwidget.h"
 #include "hk_kdeformpartwidget.h"
 #include "hk_kdereportpartwidget.h"
+#include "hk_kdemodulepartwidget.h"
 #include "hk_kdenewdatabase.h"
 #include "hk_kdedblistview.h"
 
@@ -506,6 +507,61 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
 
 
 
+
+
+  void knodamaindockwindow::slot_new_module(void)
+  {
+    if (!p_database) return;
+    hk_kdemodulepartwidget* w=new_module();
+    if (!w)return;
+    w->set_database(p_database);
+    w->setFocus();
+//     w->set_designmode();
+  }
+
+  void knodamaindockwindow::slot_delete_module(const QString& t)
+  {
+      p_database->delete_file(u2l(t.utf8().data()),ft_module);
+
+  }
+
+
+  void knodamaindockwindow::slot_designmode_module(const QString&t)
+  {
+    if (!p_database) return;
+    hk_kdemodulepartwidget* w=find_existing_module(u2l(t.utf8().data()));
+    if (w)
+    {
+      KMdiChildView* view= dynamic_cast<KMdiChildView*>(w->parent());
+      if (view)
+	 view->activate();
+    return;
+    }
+     
+     
+     w=new_module();
+    if (!w)return;
+      w->set_database(p_database);
+      w->load_module(u2l(t.utf8().data()));
+      w->setFocus();
+  }
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
   hk_kdetablepartwidget* knodamaindockwindow::new_table(void)
   {
 
@@ -651,6 +707,49 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
   }
 
 
+
+
+    hk_kdemodulepartwidget* knodamaindockwindow::new_module(void)
+  {
+   KMdiChildView* dock=new KMdiChildView(i18n("Module"),(mdiMode()==KMdi::ToplevelMode)?0L:this);
+   (new QHBoxLayout(dock))->setAutoAdd(true);
+
+    KLibFactory* p_factory= KLibLoader::self()->factory( "libhk_kdemodulepart" );
+    KParts::ReadWritePart* p_part=(KParts::ReadWritePart*) p_factory->create (dock, "hk_kdemodulepart", "KParts::ReadWritePart");
+    if (!p_part)
+    {
+     show_warningmessage(hk_translate("Fatal error! Module part could not be loaded!\nThis is a installation error. Check your installation!\
+ Did you install knoda into the correct directory? Program will exit now..."));
+     exit(1);
+    }
+     hk_kdemodulepartwidget* module = (hk_kdemodulepartwidget*)p_part->widget();
+     if (!module)
+      {
+        show_warningmessage(hk_translate("Warning! Modulepartwiget could not be created!"));
+	return NULL;
+
+      }
+      KIconLoader* loader=KGlobal::iconLoader();
+      loader->addAppDir("hk_kdeclasses");
+
+     dock->setIcon(loader->loadIcon("edit",KIcon::Small));
+     p_partmanager->addPart(p_part);
+   connect(module,SIGNAL(signal_closed(QWidget*))
+          ,this,SLOT(slot_childClosed(QWidget*)));
+   connect(dock,SIGNAL(childWindowCloseRequest(KMdiChildView*))
+          ,this,SLOT(slot_childClosed(KMdiChildView*)));
+   addWindow(dock);
+   module->setFocus();
+   
+   return module;
+  }
+
+
+
+
+
+
+
 void knodamaindockwindow::rename_clicked()
 {
 if (!p_listview) return;
@@ -972,6 +1071,25 @@ while (c)
 return NULL;
 }
 
+hk_kdemodulepartwidget* knodamaindockwindow::find_existing_module(const hk_string& n)
+{
+if (!m_pDocumentViews) return NULL;
+hk_kdemodulepartwidget* w = NULL;
+KMdiChildView* c=m_pDocumentViews->first();
+while (c)
+ { 
+  QWidget* wid=c->focusedChildWidget();
+  while (wid)
+  {
+  w=dynamic_cast<hk_kdemodulepartwidget*>(wid);
+   if (w &&  w->hk_module::name()==n) return w;
+  wid=wid->parentWidget();
+  }
+  c=m_pDocumentViews->next();
+ }
+return NULL;
+}
+
 hk_kdequerypartwidget* knodamaindockwindow::find_existing_view(const hk_string& n)
 {
 if (!m_pDocumentViews) return NULL;
