@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of knoda -Knorr's Datenbank.
 // This file may be distributed and/or modified under the terms of the
 // GNU General Public License version 2 as published by the Free Software
@@ -24,9 +24,9 @@
 #include <qfont.h>
 #include "knodawin.h"
 #include "knodaprogrambase.h"
-
+#include "knodamaindockwindowbase.h"
 #include <klocale.h>
-
+#include "knodaprogram.moc"
 #if HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -34,28 +34,11 @@
  *  Constructs a knodaprogram which is a child of 'parent', with the
  *  name 'name' and widget flags set to 'f'
  */
-knodaprogram::knodaprogram( QWidget* parent,  const char* cname, WFlags fl,parameters* p )
+knodaprogram::knodaprogram( QWidget* parent,  const char* cname, WFlags fl,struct_commandlinefields* p )
 : KMainWindow( parent, cname, fl )
 {
-    hk_string driver;
-    QString database;
-    QString form;
-    bool runtime=false;
-    bool with_workspace=false;
-    bool classiclook=false;
-    if (p)
-    {
-     driver=p->driver;
-     database=p->database;
-     form=p->form;
-     runtime=p->runtime;
-     with_workspace=p->classic_mdi;
-     classiclook=p->classic|p->classic_mdi;
-    
-    }
-    
 
-    p_mainwidget =new knodaprogrambase(this,cname,fl,driver,database,form,runtime,with_workspace,classiclook);
+    p_mainwidget =new knodaprogrambase(this,cname,fl,p);
     setCentralWidget(p_mainwidget);
     QString logoname="Knoda V ";
     logoname+=VERSION;
