@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of knoda -Knorr's Datenbank.
 // This file may be distributed and/or modified under the terms of the
 // GNU General Public License version 2 as published by the Free Software
@@ -19,24 +19,24 @@
 #include <qdialog.h>
 class hk_drivermanager;
 class knodaprogrambase;
-        typedef class parameters
+/*        typedef class parameters
 	{
 	 public:
 	   hk_string driver;
 	  QString database;
-	  QString form; 
+	  QString form;
 	  bool runtime;
 //	  bool internal;
 	  bool classic_mdi;
 	  bool classic;
-	} ;
+	} ;*/
 
 class knodaprogram : public KMainWindow
 {
     Q_OBJECT
 
         public:
-        knodaprogram( QWidget* parent = 0, const char* name = 0, WFlags fl = 0  ,parameters* p=0);
+        knodaprogram( QWidget* parent = 0, const char* name = 0, WFlags fl = 0  ,struct_commandlinefields* p=0);
         ~knodaprogram();
         void connect_clicked(void);
 
