@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of knoda -Knorr's Datenbank.
 // This file may be distributed and/or modified under the terms of the
 // GNU General Public License version 2 as published by the Free Software
@@ -8,22 +8,21 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.17 $
+//$Revision: 1.18 $
 #ifndef KNODAMAINWINDOW_H
 #define KNODAMAINWINDOW_H
 #include <kmainwindow.h>
 #include <hk_class.h>
 class hk_connection;
 class knodamainwindowbase;
-class hk_kdeworkspace;
 class KAction;
 
 class knodamainwindow :public KMainWindow, public hk_class
 {
     Q_OBJECT
         public:
-        
-	knodamainwindow( QWidget* parent = 0,hk_kdeworkspace* w=0, const char* name = 0, WFlags fl = 0,const QString& database="",const QString& form="" );
+
+	knodamainwindow( QWidget* parent = 0, const char* name = 0, WFlags fl = 0,const QString& database="",const QString& form="" );
         virtual    ~knodamainwindow();
         void set_connection(hk_connection* c);
 
